[gtk+] Revisit menu button style



commit b9c565b06c43503b881e49ff12d87175b29e9684
Author: Matthias Clasen <mclasen redhat com>
Date:   Fri Oct 30 01:07:27 2015 -0400

    Revisit menu button style
    
    Change the style class to .menubutton, to avoid interference
    from GtkMenu theming.

 gtk/gtkmenubutton.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gtk/gtkmenubutton.c b/gtk/gtkmenubutton.c
index bfe6996..54f895f 100644
--- a/gtk/gtkmenubutton.c
+++ b/gtk/gtkmenubutton.c
@@ -105,7 +105,7 @@
  * # CSS nodes
  *
  * GtkMenuButton has a single CSS node with name button. To differentiate
  * it from a plain #GtkButton, it gets the .menu style class.
  */
 
 #include "config.h"
@@ -673,7 +673,7 @@ gtk_menu_button_init (GtkMenuButton *menu_button)
   gtk_widget_set_sensitive (GTK_WIDGET (menu_button), FALSE);
 
   context = gtk_widget_get_style_context (GTK_WIDGET (menu_button));
-  gtk_style_context_add_class (context, "menu");
+  gtk_style_context_add_class (context, "menubutton");
 }
 
 /**
@@ -105,7 +105,7 @@
  *
  * GtkMenuButton has a single CSS node with name button. To differentiate
- * it from a plain #GtkButton, it gets the .menu style class.
+ * it from a plain #GtkButton, it gets the .menubutton style class.
  */
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]